@@ -42,8 +42,8 @@ enum
 static GstStateChangeReturn
 clutter_gst_auto_video_sink_change_state (GstElement     *element,
                                           GstStateChange  transition);
-static void clutter_gst_auto_video_sink_dispose (ClutterGstAutoVideoSink *sink);
-static void clutter_gst_auto_video_sink_clear_kid (ClutterGstAutoVideoSink *sink);
+static void clutter_gst_auto_video_sink_dispose (ClutterGstAutoVideoSink3 *sink);
+static void clutter_gst_auto_video_sink_clear_kid (ClutterGstAutoVideoSink3 *sink);
 
 static void clutter_gst_auto_video_sink_set_property (GObject      *object,
                                                       guint         prop_id,
@@ -55,15 +55,15 @@ static void clutter_gst_auto_video_sink_get_property (GObject    *object,
                                                       GParamSpec *pspec);
 
 #define clutter_gst_auto_video_sink_parent_class parent_class
-G_DEFINE_TYPE (ClutterGstAutoVideoSink,
+G_DEFINE_TYPE (ClutterGstAutoVideoSink3,
                clutter_gst_auto_video_sink,
                GST_TYPE_BIN)
 
-static GstStaticPadTemplate sink_template =
-  GST_STATIC_PAD_TEMPLATE ("sink",
-                           GST_PAD_SINK,
-                           GST_PAD_ALWAYS,
-                           GST_STATIC_CAPS_ANY);
+/* static GstStaticPadTemplate sink_template = */
+/*   GST_STATIC_PAD_TEMPLATE ("sink", */
+/*                            GST_PAD_SINK, */
+/*                            GST_PAD_ALWAYS, */
+/*                            GST_STATIC_CAPS_ANY); */
 
 static ClutterInitError _clutter_initialized = CLUTTER_INIT_ERROR_UNKNOWN;
 
@@ -77,7 +77,7 @@ _clutter_init (void)
 }
 
 static void
-clutter_gst_auto_video_sink_class_init (ClutterGstAutoVideoSinkClass *klass)
+clutter_gst_auto_video_sink_class_init (ClutterGstAutoVideoSink3Class *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GstElementClass *eklass = GST_ELEMENT_CLASS (klass);
@@ -108,16 +108,23 @@ clutter_gst_auto_video_sink_class_init (ClutterGstAutoVideoSinkClass *klass)
                                                         CLUTTER_GST_TYPE_CONTENT,
                                                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+  GstElement *clutter_sink = clutter_gst_create_video_sink ();
+
   gst_element_class_add_pad_template (eklass,
-                                      gst_static_pad_template_get (&sink_template));
-  gst_element_class_set_static_metadata (eklass, "Clutter Auto video sink",
+                                      gst_element_class_get_pad_template (GST_ELEMENT_GET_CLASS (clutter_sink),
+                                                                          "sink"));
+  /* gst_static_pad_template_get (&sink_template)); */
+  gst_element_class_set_static_metadata (eklass,
+                                         "Clutter Auto Video Sink",
                                          "Sink/Video",
-                                         "Video sink using a Clutter as output",
+                                         "Video sink using the Clutter scene graph as output",
                                          "Lionel Landwerlin <lionel.g.landwerlin@linux.intel.com>");
+
+  g_object_unref (clutter_sink);
 }
 
 static void
-clutter_gst_auto_video_sink_dispose (ClutterGstAutoVideoSink *sink)
+clutter_gst_auto_video_sink_dispose (ClutterGstAutoVideoSink3 *sink)
 {
   clutter_gst_auto_video_sink_clear_kid (sink);
 
@@ -125,7 +132,7 @@ clutter_gst_auto_video_sink_dispose (ClutterGstAutoVideoSink *sink)
 }
 
 static void
-clutter_gst_auto_video_sink_clear_kid (ClutterGstAutoVideoSink *sink)
+clutter_gst_auto_video_sink_clear_kid (ClutterGstAutoVideoSink3 *sink)
 {
   if (sink->kid)
     {
@@ -143,7 +150,7 @@ clutter_gst_auto_video_sink_clear_kid (ClutterGstAutoVideoSink *sink)
  */
 
 static void
-clutter_gst_auto_video_sink_reset (ClutterGstAutoVideoSink *sink)
+clutter_gst_auto_video_sink_reset (ClutterGstAutoVideoSink3 *sink)
 {
   GstPad *targetpad;
 
@@ -156,19 +163,22 @@ clutter_gst_auto_video_sink_reset (ClutterGstAutoVideoSink *sink)
 
   /* pad, setting this target should always work */
   targetpad = gst_element_get_static_pad (sink->kid, "sink");
-  gst_ghost_pad_set_target (GST_GHOST_PAD (sink->pad), targetpad);
+  if (!gst_ghost_pad_set_target (GST_GHOST_PAD (sink->pad), targetpad))
+    g_warning ("Couldn't link ghostpad's to target pad");
   gst_object_unref (targetpad);
 }
 
 static void
-clutter_gst_auto_video_sink_init (ClutterGstAutoVideoSink *sink)
+clutter_gst_auto_video_sink_init (ClutterGstAutoVideoSink3 *sink)
 {
+  sink->ts_offset = DEFAULT_TS_OFFSET;
+
   sink->pad = gst_ghost_pad_new_no_target ("sink", GST_PAD_SINK);
   gst_element_add_pad (GST_ELEMENT (sink), sink->pad);
 
   clutter_gst_auto_video_sink_reset (sink);
 
-  sink->ts_offset = DEFAULT_TS_OFFSET;
+
 
   /* mark as sink */
   GST_OBJECT_FLAG_SET (sink, GST_ELEMENT_FLAG_SINK);
@@ -180,7 +190,7 @@ clutter_gst_auto_video_sink_set_property (GObject      *object,
                                           const GValue *value,
                                           GParamSpec   *pspec)
 {
-  ClutterGstAutoVideoSink *sink = CLUTTER_GST_AUTO_VIDEO_SINK (object);
+  ClutterGstAutoVideoSink3 *sink = CLUTTER_GST_AUTO_VIDEO_SINK (object);
 
   switch (prop_id)
     {
@@ -190,8 +200,7 @@ clutter_gst_auto_video_sink_set_property (GObject      *object,
         g_object_set_property (G_OBJECT (sink->kid), pspec->name, value);
       break;
     case PROP_CONTENT:
-      if (sink->content != NULL)
-        g_clear_object (&sink->content);
+      g_clear_object (&sink->content);
       sink->content = g_value_get_object (value);
       break;
     default:
@@ -206,7 +215,7 @@ clutter_gst_auto_video_sink_get_property (GObject    *object,
                                           GValue     *value,
                                           GParamSpec *pspec)
 {
-  ClutterGstAutoVideoSink *sink = CLUTTER_GST_AUTO_VIDEO_SINK (object);
+  ClutterGstAutoVideoSink3 *sink = CLUTTER_GST_AUTO_VIDEO_SINK (object);
 
   switch (prop_id)
     {
@@ -227,7 +236,7 @@ clutter_gst_auto_video_sink_change_state (GstElement     *element,
                                           GstStateChange  transition)
 {
   GstStateChangeReturn ret = GST_STATE_CHANGE_SUCCESS;
-  ClutterGstAutoVideoSink *sink = CLUTTER_GST_AUTO_VIDEO_SINK (element);
+  ClutterGstAutoVideoSink3 *sink = CLUTTER_GST_AUTO_VIDEO_SINK (element);
 
   switch (transition) {
   case GST_STATE_CHANGE_NULL_TO_READY:
@@ -251,7 +260,7 @@ clutter_gst_auto_video_sink_change_state (GstElement     *element,
         clutter_actor_show (stage);
       }
     clutter_gst_content_set_sink (CLUTTER_GST_CONTENT (sink->content),
-                                  COGL_GST_VIDEO_SINK (sink->kid));
+                                  CLUTTER_GST_VIDEO_SINK (sink->kid));
     break;
   default:
     break;
