@@ -36,8 +36,10 @@
 #endif
 
 #include "clutter-gst-auto-video-sink.h"
+#include "clutter-gst-video-sink.h"
 
 GST_DEBUG_CATEGORY (clutter_gst_auto_video_sink_debug);
+GST_DEBUG_CATEGORY (clutter_gst_video_sink_debug);
 
 /* entry point to initialize the plug-in
   * initialize the plug-in itself
@@ -54,6 +56,11 @@ plugin_init (GstPlugin *plugin)
                            0,
                            "clutter auto video sink");
 
+  GST_DEBUG_CATEGORY_INIT (clutter_gst_video_sink_debug,
+                           "cluttervideosink",
+                           0,
+                           "clutter video sink");
+
 #if defined (CLUTTER_WINDOWING_X11)
   /* Required by some GStreamer element like VA */
   XInitThreads ();
@@ -66,12 +73,19 @@ plugin_init (GstPlugin *plugin)
   if (!ret)
     return FALSE;
 
+  ret = gst_element_register (plugin,
+                              "cluttervideosink",
+                              GST_RANK_NONE,
+                              CLUTTER_GST_TYPE_VIDEO_SINK);
+  if (!ret)
+    return FALSE;
+
   return TRUE;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
                    GST_VERSION_MINOR,
-                   clutter,
+                   clutter-gst3,
                    "Elements to render to ClutterGst actors",
                    plugin_init,
                    VERSION,
